Crate socratic

Crate socratic 

socratic is for dialog systems

Structs

Atoms
A group of atoms representing a section of text.
Dialog
Dialog stores all the dialog trees, grouped by section name.
DialogIndex
DialogIndex is used to track where in a DialogTree a player is.
DuplicateSectionKey
When merging two Dialog objects together, duplicate sections will trigger this error.
ValidationErrors
A list of validation errors

Enums

Atom
A single atom of dialog text.
DialogItem
DialogItem is a single logical dialog node to be displayed to the user.
ParseError
Error encountered while parsing dialog data.
ValidationError
Error encountered while validating

Traits

DialogState
Trait for state objects that interact with dialog.