socratic is for dialog systems
Structs
- Atoms
- A group of atoms representing a section of text.
- Dialog
- Dialog stores all the dialog trees, grouped by section name.
- Dialog
Index - DialogIndex is used to track where in a DialogTree a player is.
- Duplicate
Section Key - When merging two
Dialogobjects together, duplicate sections will trigger this error. - Validation
Errors - A list of validation errors
Enums
- Atom
- A single atom of dialog text.
- Dialog
Item - DialogItem is a single logical dialog node to be displayed to the user.
- Parse
Error - Error encountered while parsing dialog data.
- Validation
Error - Error encountered while validating
Traits
- Dialog
State - Trait for state objects that interact with dialog.